Tools Competition Winners – Futures Forum

# Tools Competition Winners

###### Launched in July 2020 at the Futures Forum on Learning, the Tools Competition generated nearly 900 proposals from 55 countries, showcasing innovative ways to accelerate learning recovery and mitigate the educational impact of COVID-19 on K-12 students. The educational tools developed by the winning teams have the potential to serve one million students by the end of 2021 and close to 20 million students within the next three years, according to estimates calculated by each team.

###### See the press release about the announcement here.

###### Download the winner information here.

Catalyst Prize Winners Up to $25,000 Mid-Range & Large Prize Winners $25,000 - $250,000

## Catalyst Prize Winners

#### Authentic Math Problems & Solutions

A platform that encourages students to use multiple approaches to solve culturally relevant math problems

Jeff King
USA

Authentic Math Problems and Solutions' platform will offer culturally relevant math problems that encourage students to collaborate with peers, iterate on their answers, and use multiple approaches to find one of many potential solutions. This is different from many existing platforms, which emphasize students independently and quickly finding a single solution to a contextless problem, like finding the hypotenuse of a triangle. With this shift in approach, this platform can better engage students from marginalized groups, starting with middle school students.

###### Team Lead

Jeff King, Software Engineer. Jeff taught high school chemistry and Chinese for five years in an urban school district that primarily served low income students from Camden, NJ. During that time, he learned to create engaging digital activities for students and is now a software engineer at Curriculum Associates where he builds products that help teachers differentiate their instruction. Outside of work, Jeff writes about edtech and is president of the Boston EdTech Foundation, a nonprofit whose mission is to help build a diverse edtech workforce.

#### Early Numeracy Learning Intervention

Phone-based app to support families foster early numeracy skills at home

Aashna Saraf & Neil Vakharia
India & USA

Early Numeracy Learning Intervention is a phone-based, gamified app that promotes the learning and regular assessment of developmentally appropriate math milestones via 14 research-backed mini-games. With personalized dashboards, feedback loops, and multiple methods for presenting a single concept, the games will work to build an understanding of foundational math skills. The goal of the app is to impact 1,000 families and partner at least with 10 schools by the end of 2021.

###### Team Leads

Aashna Saraf, Co-founder & CEO. Aashna is a senior at Pomona College majoring in Developmental Psychology. She is passionate about improving educational access and social mobility in India. Aashna seeks to drive growth and impact in early learning settings by designing play-based learning solutions that meet children where they are.

Neil Vakharia, Co-founder & CTO. Neil is a senior at Northwestern University majoring in Computer Science and Mathematics. He is passionate about technology and the various ways in which it has influenced learning over the years. Deeply involved in learning science research at the Technological Innovations for Inclusive Learning and Teaching Lab, Neil brings a wealth of educational app development experience.

#### Multimodal Toolkit

Using multimodal data to prepare the next generation of data scientists

Bertrand Schneider
USA

The Multimodal ToolKit supports data literacy–a central skill for the next generation –with two tools: a website that allows learners to collect rich multimodal dataset, from any webcam or video recording, and a platform where students can watch instructional videos, while multimodal data is collected. In analyzing this data, students improve their data analysis skills, and teachers can better understand students’ learning.

###### Team Lead

Bertrand Schneider, Assistant Professor, Harvard Graduate School of Education. Bertrand has been an assistant professor at Harvard since 2017. His interests include the development of educational interfaces (e.g., augmented reality, tangible, multitouch) for collaborative learning in formal and informal learning environments. He also researches the use of multi-modal data such as their gaze, body movement, and speech to visualize and assess students' learning trajectories.

#### Podsie

A personalized review tool that improves recall through learning science best practices

Podsie
USA

Podsie is a free learning tool for teachers that helps their students remember what they've learned. It makes it easy for teachers and students to review in an efficient and personalized way that's backed by learning science principles, like spacing and retrieval. Since Podsie is more efficient than traditional studying techniques (e.g. cramming before tests, teachers creating monthly review assignments), students can retain more information in the long term while spending less time studying.

###### Team Leads

Joshua Ling, CEO. Josh is a Teach for America alum and former middle school math teacher who believes deeply in the ability of every student to succeed. In only his second year of teaching, Josh was recognized as his school’s Teacher of the Year. After getting a master's in Education from Stanford University, he made a career change into software engineering. In addition to building Podsie, Josh also teaches an AP Computer Science Principles class at a public school in Oakland, Calif.

Jesse Mao, CTO. Jesse is a former Airbnb and Facebook software engineer who graduated with a degree in Computer Science from the University of Texas at Austin. He became interested in education while teaching web development to high school English language learner students. Jesse now aims to use his technical skills to solve problems in education.

#### TeacherPrints with LearningFlow

Analyzing classroom communication patterns to promote equitable teaching & instructional engagement

TeacherPrints
USA

TeacherPrints is a machine learning-based instructional coaching app that empowers educators around the world to turn sound recordings of their lessons–online or in-person–into useful, approachable insight about their classroom engagement patterns. TeacherPrints provides teachers with the data analysis and guidance to adjust their teaching to meet their educational goals and implement instructional practices that effectively engage all students in the learning process.

###### Team Leads

Timothy S. Slade, Data Scientist & Education Researcher, TeacherPrints & UC Berkeley. Tim is a data scientist and education researcher committed to improving the human condition. Raised in El Salvador, he has worked throughout Latin America, Africa and the eastern Mediterranean. Tim has taught and learned from students of all ages, from pre-primary through adults. He holds degrees in Data Science from the University of California, Berkeley; Early Grade Reading from the University of Massachusetts at Amherst; International Studies from North Carolina State University; and French language and Exercise and Health Science from Alma College.

Korah J. Wiley, Learning Scientist, Digital Promise. Korah has a passion for developing and investigating education technology that can provide insight into teaching and learning. She has designed professional development for STEM educators and developed numerous STEM pathway programs for under-served and first-generation college-bound students. Korah earned a Bachelor’s of Science in Biochemistry from Texas A&M University; a master’s degree in Molecular Cancer Biology from Duke University; and a Ph.D. in Science and Math Education from the University of California, Berkeley.

#### Automated Readability Tool

Open-source tool to automatically assess English texts' readability

Joon Suh Choi & Scott Crossley
USA

The Automated Readability Tool for English (ARTE) is a free, easy-to-use tool that automatically measures text readability. This team plans to adapt the currently available tool into an interactive web application to make it more accessible to teachers, administrators, researchers, and material developers. Working with an industrial partner, they will scale the app, adding new functions such as a more friendly interface, data visualization, support for REST API, and expand the number of readability formulas supported by the app.

###### Team Leads

Joon Suh Choi, Ph.D. Student in Applied Linguistics & ESL, Georgia State University. Joon’s research focuses on using natural language processing tools to match students with appropriate textual materials.

Scott A. Crossley, Professor of Applied Linguistics & ESL, Georgia State University. Sott’s interests include computational linguistics, corpus linguistics, cognitive science, discourse processing, and discourse analysis. His primary research focuses on the development and application of computational tools for understanding language learning and text comprehensibility.

#### Math with +Meaning

Mobile app that provides families ideas for culturally responsive math instruction at home

+Meaning
Chile

Math with +Meaning mobile app helps educators connect math learning with family and daily life. It brings math to life with thousands of easy-to-achieve, short and fun activities, designed for parents to carry out with their children. Each at-home activity offers with step-by-step guidance, introduces math lessons, and can be connected to the curricular content in class, which provides a greater, longer-lasting, and more meaningful learning experience for the students.

###### Team Leads

Macarena Paz Santana Sepúlveda, Founder, +Meaning & Postdoctoral Researcher in Education, Escuela de Gobierno UC, Pontificia Universidad Católica de Chile. Macarena leads research teams at EMELab and has led research projects focusing on parental engagement and socio-emotional skills. She also helped create the scope and sequence of the middle school curriculum at Texts4Teens. +Meaning is a Chilean organization that develops digital solutions for parents so they can support student learning.

Victoria Alejandra Guentulle Saavedra, Founder & CFO, +Meaning & a Ph.D. Candidate in Computer Science, Pontificia Universidad Católica de Chile. Victoria founded +Meaning in Chile to support parents in their children's learning through digital solutions. For four years beginning in 2015, Victoria was a classroom math teacher through the program Enseña Chile (from the Teach for All global network).

#### Peer Assisted Learning Systems

Peer collaboration app for middle school students

ProjectSet
India & UK

Peers Assisted Learning Systems (PALS), a moderated online chat tool, will allow disadvantaged students in middle-school to help each other in learning concepts and solving problems. It seeks to restore the peer-to-peer network in the post-pandemic online schooling world and, thereby, help maintain learning outcomes for students who lack academic support at home, as they are typically the only literate and/or school-going members in the family.

###### Team Lead

Mohuna Dutt, Head of Open Shelters, Education & Child Development Programs, the Calcutta Social Project in Calcutta, India. Mohuna joined the Calcutta Social Project in 2015 as a teacher. She now serves as the Head of Shelter overseeing education and ensuring child development. Since the onset of the COVID pandemic, Mohuna has led the online education program for urban poor children. Mohuna studied at K.C.College, Mumbai and the Event Business Academy in Oxford, England.

Dhruva, Co-founder, ProjectSet: Dhruva helped found ProjectSet, an online platform for work-based learning programs that connects students, employers and educators to collaborate virtually on internships, hackathons and course-based projects. Previously, Dhruva was a strategy consultant with Monitor Company, FOR and Index Partners. Dhruva holds a PhD in Management and a Bachelor’s degree in Engineering.

#### RecapCS

A learning tool to increase peer collaboration and deepen reflection in Computer Science

Ember Liu, Neil Thawani, & John Stamper
USA

RecapCS is a learning platform built to empower students and teachers in project-based computer science classes. On the student-facing side, RecapCS is a web dashboard with real-time Q&A from peers and instructors, a learning journey map which tracks students’ subgoals and milestones, and a resource repository to support self-teaching. RecapCS also has a Virtual Community of Practice (VCoP), where teachers are supported by their colleagues across the computing education profession.

###### Team Leads

Ember Liu & Neil Thawani, Carnegie Mellon University. Ember is a Product Designer and Neil is Software Engineer. They are both alumni of Carnegie Mellon’s METALS program, which trains graduates to apply science of learning principles, evidence-based research, and data-driven methods to design, create, and improve educational resources and technologies that enable students and instructors to succeed. They are working with John Stamper, an Assistant Professor whose research focus is using "Big Data" from educational systems to improve learning.

## Mid-Range & Large Prize Winners

#### Boost

Assignment reminders that work

Boost Education
USA

Boost is a mobile app that connects to a student's Canvas LMS account, sending assignment reminders that help students keep up with their day and do better in their courses. Boost sends real-time automated notifications and nudges to support student engagement and success, driving a 6% improvement in assignment completion and 3% increase in course completion rates. Boost empowers students to keep track of their growing online workload and to achieve their potential.

###### Team Leads

Josh Owens, CEO, Boost. Josh has received the Excellence in Teaching award as a faculty member in the Butler University Lacy School of Business. He also led SupplyKick as its CEO, won multiple industry and culture awards, and was named to the Indianapolis Business Journal’s “Forty Under 40” list. Josh was also Indiana's first openly-LGBTQ+ candidate for statewide office. He has degrees from the London School of Economics and Wabash College.

Ben Motz, Chief Research Officer, Boost. Ben is a research scientist at Indiana University where he is faculty member in the Department of Psychological and Brain Sciences and is the Director of the eLearning Research and Practice Lab. In collaboration with IU’s information technology division, Ben was one of the original designers of the Boost app. Ben’s research examines the relationships between cognitive theories of human learning and psychological theories of student engagement. He is also a lead researcher on the ManyClasses project, and is now working to develop Terracotta .

#### Kolibri

Data-driven hybrid learning for low-resource learning environments at home & at school

Learning Equality
USA

Kolibri is an adaptable set of open solutions designed to support offline-first teaching and learning. This project will enable use of Kolibri away from a classroom environment and allow underrepresented communities to participate in learning research. The combination of this functionality and previously inaccessible data for researchers will allow improved learning in the more than 200 countries and territories that are using Kolibri.

###### Team Lead

Richard Tibbles, Co-Founder & Product Lead, Learning Equality. Richard has a Ph.D. in Cognitive Science from the University of California, San Diego. Richard spent three years as a secondary science teacher in the United Kingdom and two years as an educational consultant, working in K-12 schools in New Jersey and New York where he trained teachers in problem-based learning, educational technology, and student-centered teaching.

#### NABU Formative Literacy Assessment

Measuring the impact of mother tongue books on student achievement

NABU
USA

NABU’s low-bandwidth reading app offers books to the 250 million children in developing countries who have virtually no access to books in a language they speak or understand. NABU's goal is to transform the mobile reading app into a powerful learning engineering tool that accelerates children’s literacy gains and can be scaled quickly to support millions of children with the culturally appropriate resources they need to learn to read, on devices they already have access to at home.

###### Team Leads

Tanyella Evans, Co-founder & Executive Director, NABU. Tanyella was formerly Executive Director at Artists for Peace and Justice, and worked at the Campaign for Female Education. Tanyella has over 15 years of experience in global education and leads the design of NABU’s literacy programs. Her work has been recognized by the International Literacy Association and the U.S. Library of Congress. Tanyella was named one of Forbes’ “30 under 30” in 2017, is an Echoing Green Fellow and Muhammad Ali Humanitarian Award recipient.

Rosemarie Perry, Neuroscientist & Psychologist, New York University. Rosemarie is the Founder and Executive Director of the applied research nonprofit, Social Creatures, which bridges science education, advocacy, and innovation to ensure any individual can socially connect with others, no matter their circumstances. Rosemarie also serves as a consultant researcher at New York University, where her research examines how social contexts influence child learning and biobehavioral development.

#### Speak Agent Math+Language

Boosting courses with continuous improvement & learning sciences research

Speak Agent
USA

Speak Agent Math+Language is a platform designed to improve math mastery by developing math reasoning and communication skills. The platform will be enhanced with a continuous, data-driven feedback loop to iteratively improve its course design and facilitate researchers ability to mine aggregate data and gain learning sciences insights. Specifically, the tool aims to improve student learning and to advance the learning sciences field by determining the optimal mix of Math+Language strategies to address the needs of marginalized learners.

###### Team Leads

Katie Cunningham, CTO. Katie is a leading Python expert, author, and keynote speaker. She is a leader of the Washington, DC chapter of PyLadies. She has also led linguistic research and development projects for the National Science Foundation, the National Institutes of Health, and the U.S. Department of Education. Prior to joining Speak Agent, Katie served as a technical lead at NASA.

Dan LaFountain, Ed.M., CLO. Dan is a STEM and English Language Learners teacher with 22 years experience in edtech curriculum development and partnerships. He was integral to the launch of LEGO Mindstorms and the First Robotics curriculum. Dan holds a master’s degree in education from Boston University, and a master's degree in education technology from Pepperdine University.

#### Teaching Lab Plus

Transforming the virtual teacher learning experience to accelerate K-12 student learning

Teaching Lab
USA

Teaching Lab’s professional learning platform, Teaching Lab Plus, will accelerate K-12 student learning through transformational teacher learning experiences focused on equity and, by 2023-2024, reach over 15,000 teachers and serve 1.1 million students. Teaching Lab will engage in rapid experimentation, create linked datasets and open them up to researchers to answer questions like: What leads to the greatest improvements in teacher and student learning in an online environment?

###### Team Leads

Dr. Sarah Johnson, CEO, Teaching Lab. Sarah joined Teaching Lab from the Overdeck Family Foundation, where she created and managed the Exceptional Educators Portfolio. Sarah held leadership roles at the New York City Department of Education where she managed teacher development and evaluation systems for over 70,000 teachers. She was a high school science teacher and founded a social justice student leadership program in Washington, DC and Oakland, Calif. She has a doctorate in Education Leadership from the Harvard Graduate School of Education and a Master of Arts in Teaching from American University. Sarah graduated with a bachelor’s degree in Neuroscience from Emory University.

HaMy Vu, Organizational Learning and Operations, Teaching Lab. HaMy has 15 years experience as a teacher, data analyst, education researcher, and research project manager in education. She began her career as a middle school math teacher in Philadelphia and New York City. HaMy also served as Senior Director, Research and Design at UnboundEd. Prior to that, HaMy oversaw data analysis and reporting, and policy recommendations at the Regents Research Fund and the NYC Department of Education. She holds a Bachelor’s in Science in Policy Analysis and Management from Cornell University, and a master's degree in Urban Education Policy from Brown University.

#### Graspable Math Teams

A collaborative math whiteboard

Graspable Inc.
USA

Graspable Math will facilitate synchronous, collaborative math work online. Collaborative learning, problem solving, and exchange are crucial in math education. Yet remote instruction is often limited to lecture-style lessons and solo coursework. Through this app, students will be able to jointly solve algebraic problems on an interactive, supportive algebra whiteboard with the capability to record click-stream and audio data for academic research and iterative improvements.

###### Team Leads

Erik Weitnauer, Co-founder & President, Graspable. Erik earned his Ph.D. in Cognitive Science at Bielefeld University, Germany and co-founded Graspable that same year. He is an expert in software engineering, user interfaces, full-stack development and education technology. Erik is the principal investigator in a Phase I and II Institute of Education Sciences’ Small Business Innovation Research Grant.

Erin Ottmar, Assistant Professor, Worcester Polytechnic Institute and Co-founder, Graspable. Erin holds a Ph.D. in Educational Psychology: Applied Developmental Science and conducts research on math cognition, educational technology, and student learning. Erin has been the primary researcher on four IES grants that have designed, developed, and tested Graspable Math, including an initial Institute of Education Sciences development grant, Phase I and II Small Business Innovation Research grants, and most recently an IES Efficacy grant testing From Here to There!, the game-based version of Graspable Math. She is also a licensed classroom teacher.

#### On-demand Math Tutoring

Scaling UPchieve’s one-on-one tutoring platform

UPchieve
USA

UPchieve offers a free, on-demand math tutoring platform to low-income students. UPchieve will increase access to free tutoring by building an integration that allows students using a large-scale math homework platform to speak to an UPchieve tutor when they get stuck. Linking the two platforms will 1) enable more students to discover our free services exactly when they need them, and 2) advance the field of learning engineering by creating an open data set of tutoring chat logs paired with homework problems that students got stuck on.

###### Team Lead

Aly Murray, Founder & Executive Director, UPchieve. Aly graduated summa cum laude from the University of Pennsylvania with a degree in mathematics. Her personal experience as a low-income student drives her to fight for educational equity and work toward a world in which all students have an equal opportunity to achieve upward mobility. For her work on UPchieve, Aly has been featured on the Forbes 30 Under 30 list in Education (2021) and honored as a Roddenberry Fellow (2021). In her free time, Aly volunteers as a tutor on UPchieve and as a college coach with Breakthrough New York to help other low-income students succeed.

#### Rising On Air Interactive

Interactive content to improve remote instruction

Rising Academies & Filament AI
West Africa & Canada

Rising On Air Interactive, or "Rori" for short, is a chatbot tutor, powered by AI and delivered via SMS and WhatsApp. It will sit atop Rising's unique library of structured curriculum content, including 500 hours of audio content covering language arts and math. Unlike conventional chatbots, Rori will be able to pull text and audio clips from this library, personalised to the learning needs of each individual student. The Spotify playlist for learning.

###### Team Leads

George Cowell, International Director, Rising Academies. George oversees Rising's operations across Liberia, Sierra Leone and Ghana, and coordinates Rising’s distance learning platform: Rising On Air. He has degrees from the University of Exeter and the Institute of Education.

Col Elliott-Kelly, Chief Strategy Officer, FilamentAI. Col runs Filament North America and drives strategic planning for the global business including international growth, ventures, corporate development and product strategy. Previously, he founded and led the Education division of Blippar, an augmented reality and artificial intelligence startup based in London. Col has a master's degree in Classics and French from the University of Oxford.

#### Springboard's At-Home Literacy Screener

Leveraging technology to democratize assessment & equip families to support literacy at home

Springboard Collaborative
USA

Powered by speech recognition and AI, the Parent-Facing Literacy Screener (PFLS) will automate literacy assessment such that it requires neither classroom time nor teaching expertise to administer. PFLS will enable families to more deeply understand their children’s reading development, set goals, and measure progress. The data, in turn, will enable Springboard to personalize strategies that families and teachers can use to accelerate student learning.

###### Team Leads

Alejandro Gibes de Gac, CEO & Founder, Springboard Collaborative. Alejandro was named “one of the world’s best emerging social innovators” by Echoing Green, one of Forbes’ “30 under 30,” and was one of two national recipients of the Claneil Emerging Leaders Fund. Alejandro is an alumnus of Teach for America and worked for McKinsey & Co.. He graduated with high honors from Harvard University, and has a master’s degree in Urban Education from the University of Pennsylvania.

Greg Sampson, VP of Engineering, Systems, & Products, Springboard Collaborative. Greg leads Springboard Collaborative’s technical product strategy and solutions development. He has more than 25 years of experience in tech development and management, has taught in the Philadelphia public schools, and is an adjunct professor at Howard University. Prior to joining Springboard, Greg was the Director of Engineering and Program Management at Red Lion Controls. Greg holds a bachelor's degree in Computer Engineering from Howard University where he is a member of the Alumni Curriculum Advisory Committee.

×

No Video Found